@@ -1,7 +1,7 @@
 from .api_client import NutanixApiClient, NutanixSession
 from .nutanix_cluster import ClusterMetadata, ClusterSpec, ClusterStatus, NutanixCluster
 from .nutanix_image import ImageMetadata, ImageSpec, ImageStatus, NutanixImage
-from .nutanix_vm import NutanixVM, NutanixVMLabel, PowerState, VMMetadata, VMSpec, VMStatus
+from .nutanix_vm import NutanixVM, NutanixVMLabel, PowerState, VMBootDevices, VMMetadata, VMSpec, VMStatus
 
 __all__ = [
     "PowerState",
@@ -22,4 +22,5 @@ __all__ = [
     "ClusterSpec",
     "exceptions",
     "NutanixVMLabel",
+    "VMBootDevices",
 ]
